@@ -5,6 +5,8 @@ import (
 	"fmt"
 
 	"github.com/goreleaser/goreleaser/internal/middleware"
+	"github.com/goreleaser/goreleaser/internal/pipe/reddit"
+	"github.com/goreleaser/goreleaser/internal/pipe/slack"
 	"github.com/goreleaser/goreleaser/internal/pipe/twitter"
 	"github.com/goreleaser/goreleaser/pkg/context"
 )
@@ -26,6 +28,8 @@ type Announcer interface {
 // nolint: gochecknoglobals
 var announcers = []Announcer{
 	twitter.Pipe{}, // announce to twitter
+	reddit.Pipe{},  // announce to twitter
+	slack.Pipe{},   // announce to slack
 }
 
 // Run the pipe.
