@@ -3,10 +3,12 @@
 package defaults
 
 import (
+	"fmt"
 	"strings"
 
 	"github.com/goreleaser/goreleaser/internal/client"
 	"github.com/goreleaser/goreleaser/internal/middleware"
+	"github.com/goreleaser/goreleaser/internal/tmpl"
 	"github.com/goreleaser/goreleaser/pkg/context"
 	"github.com/goreleaser/goreleaser/pkg/defaults"
 )
@@ -30,7 +32,12 @@ func (Pipe) Run(ctx *context.Context) error {
 		ctx.Config.GitLabURLs.Download = client.DefaultGitLabDownloadURL
 	}
 	if ctx.Config.GiteaURLs.Download == "" {
-		ctx.Config.GiteaURLs.Download = strings.ReplaceAll(ctx.Config.GiteaURLs.API, "/api/v1", "")
+		apiURL, err := tmpl.New(ctx).Apply(ctx.Config.GiteaURLs.API)
+		if err != nil {
+			return fmt.Errorf("templating Gitea API URL: %w", err)
+		}
+
+		ctx.Config.GiteaURLs.Download = strings.ReplaceAll(apiURL, "/api/v1", "")
 	}
 	for _, defaulter := range defaults.Defaulters {
 		if err := middleware.Logging(
