@@ -5,7 +5,7 @@ package static
 
 // ExampleConfig is the config used within goreleaser init.
 const ExampleConfig = `# This is an example .goreleaser.yml file with some sane defaults.
-# Make sure to check the documentation at http://goreleaser.com
+# Make sure to check the documentation at https://goreleaser.com
 before:
   hooks:
     # You may remove this if you don't use go modules.
