@@ -90,27 +90,28 @@ func (r Repo) String() string {
 
 // Homebrew contains the brew section.
 type Homebrew struct {
-	Name             string               `yaml:",omitempty"`
-	Tap              RepoRef              `yaml:",omitempty"`
-	CommitAuthor     CommitAuthor         `yaml:"commit_author,omitempty"`
-	Folder           string               `yaml:",omitempty"`
-	Caveats          string               `yaml:",omitempty"`
-	Plist            string               `yaml:",omitempty"`
-	Install          string               `yaml:",omitempty"`
-	PostInstall      string               `yaml:"post_install,omitempty"`
-	Dependencies     []HomebrewDependency `yaml:",omitempty"`
-	Test             string               `yaml:",omitempty"`
-	Conflicts        []string             `yaml:",omitempty"`
-	Description      string               `yaml:",omitempty"`
-	Homepage         string               `yaml:",omitempty"`
-	License          string               `yaml:",omitempty"`
-	SkipUpload       string               `yaml:"skip_upload,omitempty"`
-	DownloadStrategy string               `yaml:"download_strategy,omitempty"`
-	URLTemplate      string               `yaml:"url_template,omitempty"`
-	CustomRequire    string               `yaml:"custom_require,omitempty"`
-	CustomBlock      string               `yaml:"custom_block,omitempty"`
-	IDs              []string             `yaml:"ids,omitempty"`
-	Goarm            string               `yaml:"goarm,omitempty"`
+	Name                  string               `yaml:",omitempty"`
+	Tap                   RepoRef              `yaml:",omitempty"`
+	CommitAuthor          CommitAuthor         `yaml:"commit_author,omitempty"`
+	CommitMessageTemplate string               `yaml:"commit_msg_template,omitempty"`
+	Folder                string               `yaml:",omitempty"`
+	Caveats               string               `yaml:",omitempty"`
+	Plist                 string               `yaml:",omitempty"`
+	Install               string               `yaml:",omitempty"`
+	PostInstall           string               `yaml:"post_install,omitempty"`
+	Dependencies          []HomebrewDependency `yaml:",omitempty"`
+	Test                  string               `yaml:",omitempty"`
+	Conflicts             []string             `yaml:",omitempty"`
+	Description           string               `yaml:",omitempty"`
+	Homepage              string               `yaml:",omitempty"`
+	License               string               `yaml:",omitempty"`
+	SkipUpload            string               `yaml:"skip_upload,omitempty"`
+	DownloadStrategy      string               `yaml:"download_strategy,omitempty"`
+	URLTemplate           string               `yaml:"url_template,omitempty"`
+	CustomRequire         string               `yaml:"custom_require,omitempty"`
+	CustomBlock           string               `yaml:"custom_block,omitempty"`
+	IDs                   []string             `yaml:"ids,omitempty"`
+	Goarm                 string               `yaml:"goarm,omitempty"`
 }
 
 // Scoop contains the scoop.sh section.
@@ -533,10 +534,11 @@ type Snapshot struct {
 
 // Checksum config.
 type Checksum struct {
-	NameTemplate string   `yaml:"name_template,omitempty"`
-	Algorithm    string   `yaml:"algorithm,omitempty"`
-	IDs          []string `yaml:"ids,omitempty"`
-	Disable      bool     `yaml:"disable,omitempty"`
+	NameTemplate string      `yaml:"name_template,omitempty"`
+	Algorithm    string      `yaml:"algorithm,omitempty"`
+	IDs          []string    `yaml:"ids,omitempty"`
+	Disable      bool        `yaml:"disable,omitempty"`
+	ExtraFiles   []ExtraFile `yaml:"extra_files,omitempty"`
 }
 
 // Docker image config.
@@ -690,6 +692,8 @@ type GoMod struct {
 
 type Announce struct {
 	Twitter Twitter `yaml:"twitter,omitempty"`
+	Reddit  Reddit  `yaml:"reddit,omitempty"`
+	Slack   Slack   `yaml:"slack,omitempty"`
 }
 
 type Twitter struct {
@@ -697,6 +701,24 @@ type Twitter struct {
 	MessageTemplate string `yaml:"message_template,omitempty"`
 }
 
+type Reddit struct {
+	Enabled       bool   `yaml:"enabled,omitempty"`
+	ApplicationID string `yaml:"application_id,omitempty"`
+	Username      string `yaml:"username,omitempty"`
+	TitleTemplate string `yaml:"title_template,omitempty"`
+	URLTemplate   string `yaml:"url_template,omitempty"`
+	Sub           string `yaml:"sub,omitempty"`
+}
+
+type Slack struct {
+	Enabled         bool   `yaml:"enabled,omitempty"`
+	MessageTemplate string `yaml:"message_template,omitempty"`
+	Channel         string `yaml:"channel,omitempty"`
+	Username        string `yaml:"username,omitempty"`
+	IconEmoji       string `yaml:"icon_emoji,omitempty"`
+	IconURL         string `yaml:"icon_url,omitempty"`
+}
+
 // Load config file.
 func Load(file string) (config Project, err error) {
 	f, err := os.Open(file) // #nosec
